# langchain-sema4

This package contains the LangChain integrations for [Robocorp Action Server](https://github.com/sema4/sema4).
Action Server enables an agent to execute actions in the real world. 

## Installation

```bash
pip install -U langchain-sema4
```

## Action Server Toolkit

See [ActionServerToolkit](https://python.langchain.com/docs/integrations/toolkits/sema4) for detailed documentation.
